@@ -25,7 +25,7 @@ def upsacale(image,cvdnn_path):
 def inference(img_path,ocr,cvdnn_path):
     try:
         machineid = subprocess.run(['cat', '/etc/machine-id'], stdout=subprocess.PIPE)
-        if(machineid.stdout.decode('utf-8').rstrip() in ["4c44501bf7b14db9a99e21cc0fb0abfe"]):
+        if(machineid.stdout.decode('utf-8').rstrip() in ["4c44501bf7b14db9a99e21cc0fb0abfe","a3d9197b765643568af09eb2bd3e5ce7"]):
             print("Configured Sucessfully")
             image= cv2.imread(img_path)
             img_path=upsacale(image,cvdnn_path)
